#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_ALL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_ALL_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/all.hpp>

#endif
